@@ -1,11 +1,11 @@
 /*
- * eval.h
+ * Copyright (C) 1998-2002 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2000-2017 the AUTHORS
  *
- * by Gary Wong <gary@cs.arizona.edu>, 1998-2001.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: eval.h,v 1.189 2014/09/08 21:11:51 plm Exp $
+ * $Id: eval.h,v 1.201 2024/01/02 21:14:07 plm Exp $
  */
 
 #ifndef EVAL_H
@@ -33,8 +32,8 @@
 	extern ret name##NoLocking( __VA_ARGS__); \
 	extern ret name##WithLocking( __VA_ARGS__)
 
-#define WEIGHTS_VERSION "1.00"
-#define WEIGHTS_VERSION_BINARY 1.00f
+#define WEIGHTS_VERSION "1.01"
+#define WEIGHTS_VERSION_BINARY 1.01f
 #define WEIGHTS_MAGIC_BINARY 472.3782f
 
 #define NUM_OUTPUTS 5
@@ -92,6 +91,7 @@ typedef struct {
     unsigned int nPlies:4;
     unsigned int fUsePrune:1;
     unsigned int fDeterministic:1;
+    unsigned int :25;		/* padding */
     float rNoise;               /* standard deviation */
 } evalcontext;
 
@@ -131,8 +131,8 @@ typedef struct {
     unsigned short nLate;       /* switch evaluations on move nLate of game */
     rng rngRollout;
     unsigned long nSeed;
-    unsigned int nMinimumGames; /* but always do at least this many */
-    float rStdLimit;           /* stop when abs( value / std ) < this */
+    unsigned int nMinimumGames; /* always do at least this many */
+    float rStdLimit;            /* stop when std < this */
     unsigned int nMinimumJsdGames;
     float rJsdLimit;
     unsigned int nGamesDone;
@@ -161,7 +161,7 @@ extern const char *aszVariations[NUM_VARIATIONS];
 extern const char *aszVariationCommands[NUM_VARIATIONS];
 
 /*
- * Cubeinfo contains the information necesary for evaluation
+ * Cubeinfo contains the information necessary for evaluation
  * of a position.
  * These structs are placed here so that the move struct can be defined
  */
@@ -298,12 +298,12 @@ typedef struct {
 /* cube efficiencies */
 
 extern float rOSCubeX;
-extern float rRaceFactorX;
-extern float rRaceCoefficientX;
-extern float rRaceMax;
-extern float rRaceMin;
-extern float rCrashedX;
-extern float rContactX;
+extern float rRaceFactorX[2];
+extern float rRaceCoefficientX[2];
+extern float rRaceMax[2];
+extern float rRaceMin[2];
+extern float rCrashedX[2];
+extern float rContactX[2];
 
 /* position classes */
 
@@ -380,6 +380,9 @@ extern int
 extern int
  KeithCount(const TanBoard anBoard, int pn[2]);
 
+extern int
+ IsightCount(const TanBoard anBoard, int pn[2]);
+
 extern int
  DumpPosition(const TanBoard anBoard, char *szOutput,
              const evalcontext * pec, cubeinfo * pci, int fOutputMWC,
@@ -425,10 +428,6 @@ extern int
  SetCubeInfoMoney(cubeinfo * pci, const int nCube, const int fCubeOwner,
                  const int fMove, const int fJacoby, const int fBeavers, const bgvariation bgv);
 
-extern int
- SetCubeInfoMatch(cubeinfo * pci, const int nCube, const int fCubeOwner,
-                 const int fMove, const int nMatchTo, const int anScore[2], const int fCrawford, const bgvariation bgv);
-
 extern int
  SetCubeInfo(cubeinfo * pci, const int nCube, const int fCubeOwner,
             const int fMove, const int nMatchTo, const int anScore[2],
@@ -443,9 +442,6 @@ extern void
 extern void
  SanityCheck(const TanBoard anBoard, float arOutput[]);
 
-extern int
- EvalBearoff1(const TanBoard anBoard, float arOutput[], const bgvariation bgv, NNState * nnStates);
-
 extern int
  EvalOver(const TanBoard anBoard, float arOutput[], const bgvariation bgv, NNState * nnStates);
 
@@ -456,16 +452,16 @@ extern int
  GetDPEq(int *pfCube, float *prDPEq, const cubeinfo * pci);
 
 extern float
- mwc2eq(const float rMwc, const cubeinfo * ci);
+ mwc2eq(const float rMwc, const cubeinfo * pci);
 
 extern float
- eq2mwc(const float rEq, const cubeinfo * ci);
+ eq2mwc(const float rEq, const cubeinfo * pci);
 
 extern float
- se_mwc2eq(const float rMwc, const cubeinfo * ci);
+ se_mwc2eq(const float rMwc, const cubeinfo * pci);
 
 extern float
- se_eq2mwc(const float rEq, const cubeinfo * ci);
+ se_eq2mwc(const float rEq, const cubeinfo * pci);
 
 extern char
 *FormatEval(char *sz, evalsetup * pes);
@@ -484,9 +480,6 @@ extern int
 extern int
  cmp_evalcontext(const evalcontext * pec1, const evalcontext * pec2);
 
-extern int
- cmp_rolloutcontext(const rolloutcontext * prc1, const rolloutcontext * prc2);
-
 extern char
 *GetCubeRecommendation(const cubedecision cd);
 
@@ -497,9 +490,6 @@ extern int
  getCurrentGammonRates(float aarRates[2][2],
                       float arOutput[], const TanBoard anBoard, cubeinfo * pci, const evalcontext * pec);
 
-extern void
- calculate_gammon_rates(float aarRates[2][2], float arOutput[], cubeinfo * pci);
-
 extern void
  getMoneyPoints(float aaarPoints[2][7][2], const int fJacoby, const int fBeavers, float aarRates[2][2]);
 
@@ -532,14 +522,11 @@ extern unsigned int
  locateMove(const TanBoard anBoard, const int anMove[8], const movelist * pml);
 
 extern int
- MoveKey(const TanBoard anBoard, const int anMove[8], positionkey * pkey);
-
-extern int
- equal_movefilter(const int i, movefilter amf1[MAX_FILTER_PLIES], movefilter amf2[MAX_FILTER_PLIES]);
+ equal_movefilter(const int i, const movefilter amf1[MAX_FILTER_PLIES], const movefilter amf2[MAX_FILTER_PLIES]);
 
 extern int
  equal_movefilters(movefilter aamf1[MAX_FILTER_PLIES][MAX_FILTER_PLIES],
-                  movefilter aamf2[MAX_FILTER_PLIES][MAX_FILTER_PLIES]);
+                   movefilter aamf2[MAX_FILTER_PLIES][MAX_FILTER_PLIES]);
 
 extern doubletype DoubleType(const int fDoubled, const int fMove, const int fTurn);
 
@@ -549,11 +536,8 @@ extern int
 extern void
  baseInputs(const TanBoard anBoard, float arInput[]);
 
-extern void
- CalculateRaceInputs(const TanBoard anBoard, float inputs[]);
-
 extern int CompareMoves(const move * pm0, const move * pm1);
-extern float EvalEfficiency(const TanBoard anBoard, positionclass pc);
+extern float EvalEfficiency(const TanBoard anBoard, positionclass pc, int ply);
 extern float Cl2CfMoney(float arOutput[NUM_OUTPUTS], cubeinfo * pci, float rCubeX);
 extern float Cl2CfMatch(float arOutput[NUM_OUTPUTS], cubeinfo * pci, float rCubeX);
 extern float Noise(const evalcontext * pec, const TanBoard anBoard, int iOutput);
