@@ -1,11 +1,11 @@
 /*
- * export.c
+ * Copyright (C) 2002-2003 Joern Thyssen <jthyssen@dk.ibm.com>
+ * Copyright (C) 2002-2019 the AUTHORS
  *
- * by Joern Thyssen  <jthyssen@dk.ibm.com>, 2002
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: export.c,v 1.79 2014/01/24 22:53:28 plm Exp $
+ * $Id: export.c,v 1.100 2024/01/31 19:26:12 plm Exp $
  */
 
 #include "config.h"
@@ -28,7 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 #include <png.h>
 #endif
 
@@ -36,13 +35,14 @@
 #include "drawboard.h"
 #include "export.h"
 #include "eval.h"
+#include "list.h"
 #include "positionid.h"
 #include "renderprefs.h"
 #include "matchid.h"
 #include "boardpos.h"
 #include "boarddim.h"
 
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
 #include <cairo.h>
 #include <cairo-svg.h>
 #include <cairo-pdf.h>
@@ -62,7 +62,7 @@
  *   iGame: game number
  *
  * Garbage collect:
- *   Caller must free returned pointer if not NULL
+ *   Caller must g_free returned pointer
  * 
  */
 
@@ -73,12 +73,12 @@ filename_from_iGame(const char *szBase, const int iGame)
         return g_strdup(szBase);
     else {
         char *sz = g_malloc(strlen(szBase) + 5);
-        char *szExtension = strrchr(szBase, '.');
-        char *pc;
+        const char *szExtension = strrchr(szBase, '.');
         if (!szExtension) {
             sprintf(sz, "%s_%03d", szBase, iGame + 1);
             return sz;
         } else {
+            char *pc;
             strcpy(sz, szBase);
             pc = strrchr(sz, '.');
             sprintf(pc, "_%03d%s", iGame + 1, szExtension);
@@ -87,7 +87,9 @@ filename_from_iGame(const char *szBase, const int iGame)
     }
 }
 
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
+
+/* Caller must g_free returned pointer */
 static gchar *
 export_get_filename(char *sz)
 {
@@ -163,8 +165,7 @@ draw_simple_board_on_cairo(matchstate * sb_pms,
 
     simple_board_draw(board);
     g_free(board);
-    if (header)
-        g_string_free(header, TRUE);
+    g_string_free(header, TRUE);
     if (annotation)
         g_string_free(annotation, TRUE);
     return 1;
@@ -176,10 +177,8 @@ export_boards(moverecord * pmr, matchstate * msExport, int *iMove, int iGame, ca
     FixMatchState(msExport, pmr);
     switch (pmr->mt) {
     case MOVE_NORMAL:
-        if (pmr->fPlayer != msExport->fMove) {
+        if (pmr->fPlayer != msExport->fMove)
             SwapSides(msExport->anBoard);
-            msExport->fMove = pmr->fPlayer;
-        }
         msExport->fTurn = msExport->fMove = pmr->fPlayer;
         msExport->anDice[0] = pmr->anDice[0];
         msExport->anDice[1] = pmr->anDice[1];
@@ -223,7 +222,7 @@ draw_cairo_pages(cairo_t * cairo, listOLD * game_ptr)
     psc = &pmr->g.sc;
     AddStatcontext(psc, &scTotal);
     iGame = getGameNumber(game_ptr);
-    if (game_is_last(plGame))
+    if (game_is_last(game_ptr))
         pl_hint = game_add_pmr_hint(game_ptr);
     for (pl = pl->plNext, page = 1; pl != game_ptr; pl = pl->plNext, page++) {
         export_boards(pl->p, &msExport, &iMove, iGame, cairo, SIZE_2PERPAGE);
@@ -248,13 +247,12 @@ draw_cairo_pages(cairo_t * cairo, listOLD * game_ptr)
 extern void
 CommandExportPositionSVG(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
     moverecord *pmr;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     if (!CheckGameExists())
         return;
@@ -262,14 +260,19 @@ CommandExportPositionSVG(char *sz)
     filename = export_get_filename(sz);
     if (!filename)
         return;
+
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
+
     surface = cairo_svg_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT / 2.0);
+    g_free(filename);
+
     if (surface) {
-        cairo = cairo_create(surface);
+        cairo_t *cairo = cairo_create(surface);
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
         cairo_surface_destroy(surface);
         cairo_destroy(cairo);
@@ -281,13 +284,12 @@ CommandExportPositionSVG(char *sz)
 extern void
 CommandExportPositionPDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
     moverecord *pmr;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     if (!CheckGameExists())
         return;
@@ -295,14 +297,20 @@ CommandExportPositionPDF(char *sz)
     filename = export_get_filename(sz);
     if (!filename)
         return;
+
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
+
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
-        cairo = cairo_create(surface);
+        cairo_t *cairo = cairo_create(surface);
+
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
         cairo_surface_destroy(surface);
         cairo_destroy(cairo);
@@ -314,13 +322,12 @@ CommandExportPositionPDF(char *sz)
 extern void
 CommandExportPositionPS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
     moverecord *pmr;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     if (!CheckGameExists())
         return;
@@ -328,15 +335,20 @@ CommandExportPositionPS(char *sz)
     filename = export_get_filename(sz);
     if (!filename)
         return;
+
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
 
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
-        cairo = cairo_create(surface);
+        cairo_t *cairo = cairo_create(surface);
+
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
         cairo_surface_destroy(surface);
         cairo_destroy(cairo);
@@ -348,10 +360,9 @@ CommandExportPositionPS(char *sz)
 extern void
 CommandExportGamePDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     if (!CheckGameExists())
         return;
@@ -360,8 +371,11 @@ CommandExportGamePDF(char *sz)
     if (!filename)
         return;
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
-        cairo = cairo_create(surface);
+        cairo_t *cairo = cairo_create(surface);
+
         draw_cairo_pages(cairo, plGame);
         cairo_surface_destroy(surface);
         cairo_destroy(cairo);
@@ -373,10 +387,9 @@ CommandExportGamePDF(char *sz)
 extern void
 CommandExportGamePS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     if (!CheckGameExists())
         return;
@@ -385,8 +398,11 @@ CommandExportGamePS(char *sz)
     if (!filename)
         return;
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
-        cairo = cairo_create(surface);
+        cairo_t *cairo = cairo_create(surface);
+
         draw_cairo_pages(cairo, plGame);
         cairo_surface_destroy(surface);
         cairo_destroy(cairo);
@@ -398,20 +414,23 @@ CommandExportGamePS(char *sz)
 extern void
 CommandExportMatchPDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     listOLD *pl;
-    int nGames = 0;
-    int i;
     char *filename;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     filename = export_get_filename(sz);
 
     if (!filename)
         return;
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
+        cairo_t *cairo;
+        int nGames = 0;
+        int i;
+
         for (pl = lMatch.plNext; pl != &lMatch; pl = pl->plNext, nGames++);
 
         cairo = cairo_create(surface);
@@ -428,20 +447,23 @@ CommandExportMatchPDF(char *sz)
 extern void
 CommandExportMatchPS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     listOLD *pl;
-    int nGames = 0;
-    int i;
     char *filename;
     cairo_surface_t *surface;
-    cairo_t *cairo;
 
     filename = export_get_filename(sz);
 
     if (!filename)
         return;
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
+
     if (surface) {
+        cairo_t *cairo;
+        int nGames = 0;
+        int i;
+
         for (pl = lMatch.plNext; pl != &lMatch; pl = pl->plNext, nGames++);
 
         cairo = cairo_create(surface);
@@ -455,9 +477,9 @@ CommandExportMatchPS(char *sz)
         outputerrf(_("Failed to create cairo surface for %s"), sz);
 }
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 
-/* size of html images in steps of BOARD_WIDTH x BOARD_HEIGHT
+/* size of HTML images in steps of BOARD_WIDTH x BOARD_HEIGHT
  * as defined in boarddim.h */
 
 extern int
@@ -468,7 +490,6 @@ WritePNG(const char *sz, unsigned char *puch, unsigned int nStride, unsigned int
     png_structp ppng;
     png_infop pinfo;
     png_text atext[3];
-    unsigned int i;
 
     if (!(pf = g_fopen(sz, "wb")))
         return -1;
@@ -503,7 +524,7 @@ WritePNG(const char *sz, unsigned char *puch, unsigned int nStride, unsigned int
     atext[0].text = "Backgammon board";
     atext[0].compression = PNG_TEXT_COMPRESSION_NONE;
 
-    atext[1].key = "author";
+    atext[1].key = "Author";
     atext[1].text = VERSION_STRING;
     atext[1].compression = PNG_TEXT_COMPRESSION_NONE;
 
@@ -511,12 +532,15 @@ WritePNG(const char *sz, unsigned char *puch, unsigned int nStride, unsigned int
     atext[0].lang = NULL;
     atext[1].lang = NULL;
 #endif
+
     png_set_text(ppng, pinfo, atext, 2);
 
     png_write_info(ppng, pinfo);
 
     {
-        png_bytep *aprow = (png_bytep *) g_alloca(nSizeY * sizeof(png_bytep));;
+        png_bytep *aprow = (png_bytep *) g_alloca(nSizeY * sizeof(png_bytep));
+        unsigned int i;
+
         for (i = 0; i < nSizeY; ++i)
             aprow[i] = puch + nStride * i;
 
@@ -607,7 +631,7 @@ GenerateImage(renderimages * pri, renderdata * prd,
     color = fMove;
 
     CalculateArea(prd, puch, BOARD_WIDTH * nSize * 3, pri, anBoardTemp, NULL,
-                  (int *) anDice, anDicePosition,
+                  anDice, anDicePosition,
                   color, anCubePosition,
                   LogCube(nCube) + (doubled != 0),
                   nOrient,
@@ -659,7 +683,7 @@ CommandExportPositionPNG(char *sz)
 
     /* generate PNG image */
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (GetMainAppearance()->fDisplayType == DT_3D) {
         GenerateImage3d(sz, exsExport.nPNGSize, BOARD_WIDTH, BOARD_HEIGHT);
     } else
@@ -721,7 +745,7 @@ ExportSnowieTxt(char *sz, const matchstate * pms)
 
     sz += sprintf(sz, "%s;%s;", ap[pms->fMove].szName, ap[!pms->fMove].szName);
 
-    /* crawford game */
+    /* Crawford game */
 
     i = pms->nMatchTo &&
         ((pms->anScore[0] == (pms->nMatchTo - 1)) ||
@@ -766,11 +790,11 @@ ExportSnowieTxt(char *sz, const matchstate * pms)
 
     /* chequers on the bar for opponent */
 
-    sz += sprintf(sz, "%d;", pms->anBoard[1][24]);
+    sz += sprintf(sz, "%u;", pms->anBoard[1][24]);
 
     /* dice */
 
-    sprintf(sz, "%d;%d;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
+    sprintf(sz, "%u;%u;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
 
 }
 
@@ -942,7 +966,7 @@ CommandExportPositionJF(char *sz)
             goto write_failed;
     }
 
-    if (!WriteInt16(fp, 0))     /* FIXME Check gnubg setting */
+    if (!WriteInt16(fp, 0))     /* FIXME Check GNUbg setting */
         goto write_failed;
     /* TRUE if lower die is to be drawn to the left */
 
@@ -1015,6 +1039,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
     matchstate msExport;
     char sz[128], buffer[256];
     int i = 0, n, nFileCube = 1, fWarned = FALSE, diceRolled = 0;
+    int nDoubles = 0;
     TanBoard anBoard;
 
     /* FIXME It would be nice if this function was updated to use the
@@ -1030,7 +1055,15 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
     InitBoard(anBoard, ms.bgv);
 
     for (pl = plGame->plNext; pl != plGame; pl = pl->plNext) {
+        if (pl == NULL) {
+            g_assert_not_reached();
+            break;
+        }
         pmr = pl->p;
+        if (pmr == NULL) {
+            g_assert_not_reached();
+            break;
+        }
         switch (pmr->mt) {
         case MOVE_GAMEINFO:
             if (withScore) {
@@ -1047,36 +1080,56 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
                 fprintf(pf, " %-31s%s\n", ap[0].szName, ap[1].szName);
             msExport.fCubeOwner = -1;
             /* FIXME what about automatic doubles? */
-            continue;
-            break;
+            continue;           /* branch out of the switch and continue for (pl ...) */
         case MOVE_NORMAL:
             diceRolled = 0;
             sprintf(sz, "%u%u: ", pmr->anDice[0], pmr->anDice[1]);
             if (fSst) {         /* Snowie standard text */
-                moverecord *pnextmr;
                 if (pl->plNext && pl->plNext->p) {
-                    pnextmr = pl->plNext->p;
+                    const moverecord *pnextmr = pl->plNext->p;
                     if (pnextmr->mt == MOVE_SETBOARD)
-                        /* Illegal move entered in gnubg as bogus move followed by
+                        /* Illegal move entered in GNUbg as bogus move followed by
                          * editing position : don't export the move, only the dice */
                         diceRolled = 1;
                     else
-                        FormatMovePlain(sz + 4, anBoard, pmr->n.anMove);
+                        FormatMovePlain(sz + 4, (ConstTanBoard)anBoard, pmr->n.anMove);
                 } else
-                    FormatMovePlain(sz + 4, anBoard, pmr->n.anMove);
+                    FormatMovePlain(sz + 4, (ConstTanBoard)anBoard, pmr->n.anMove);
             } else
-                FormatMovePlain(sz + 4, anBoard, pmr->n.anMove);
+                FormatMovePlain(sz + 4, (ConstTanBoard)anBoard, pmr->n.anMove);
             ApplyMove(anBoard, pmr->n.anMove, FALSE);
             SwapSides(anBoard);
             /*   if (( sz[ strlen(sz)-1 ] == ' ') && (strlen(sz) > 5 ))
              * sz[ strlen(sz) - 1 ] = 0;  Don't need this..  */
+            nDoubles = 0;
             break;
         case MOVE_DOUBLE:
-            sprintf(sz, " Doubles => %d", nFileCube <<= 1);
-            msExport.fCubeOwner = !(i & 1);
+            if (nDoubles == 0) {
+                sprintf(sz, " Doubles => %d", nFileCube <<= 1);
+                msExport.fCubeOwner = !(i & 1);
+            } else {
+                /* Jellyfish uses this, not "Doubles" */
+                sprintf(sz, " Beavers => %d", nFileCube <<= 1);
+            }
+            nDoubles++;
             break;
         case MOVE_TAKE:
-            strcpy(sz, " Takes");       /* FIXME beavers? */
+            /* Don't print "Takes" after a beaver or the following moves
+             * will be swapped between players. This is Jellyfish's behaviour.
+             * It supported only one beaver. We print either filler spaces
+             * or nothing depending on the number of redoubles to get the
+             * following moves in the right column.
+             */
+            if (nDoubles % 2)
+                if (nDoubles == 1)
+                    strcpy(sz, " Takes");
+                else
+                    strcpy(sz, "  ");
+            else {
+                nDoubles = 0;
+                continue;
+            }
+            nDoubles = 0;
             break;
         case MOVE_DROP:
             sprintf(sz, " Drops%sWins %d point%s",
@@ -1116,23 +1169,35 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
                 SwapSides(anBoard);
 
             if (fSst) {         /* Snowie standard text */
-                moverecord *pnextmr = pl->plNext->p;
-                char *ct;
+                if (pl->plNext == NULL) {
+                    fprintf(pf, "Unexportable play (%s)\n", buffer);
+                    g_assert_not_reached();
+                } else if (pl->plNext->p == NULL) {
+                    fprintf(pf, "Unexportable play (%s)\n", buffer);
+                    g_assert_not_reached();
+                } else {
+                    const moverecord *pnextmr = pl->plNext->p;
+		    char *ct;
 
-                msExport.nMatchTo = ms.nMatchTo;
-                msExport.nCube = nFileCube;
-                msExport.fMove = (i & 1);
-                msExport.fTurn = (i & 1);
-                PositionFromKey(msExport.anBoard, &pmr->sb.key);
-                msExport.anDice[0] = pnextmr->anDice[0];
-                msExport.anDice[1] = pnextmr->anDice[1];
-                if (i & 1)
-                    SwapSides(msExport.anBoard);
-                ExportSnowieTxt(buffer, &msExport);
+                    msExport.nMatchTo = ms.nMatchTo;
+                    msExport.nCube = nFileCube;
+                    msExport.fMove = (i & 1);
+                    msExport.fTurn = (i & 1);
+                    PositionFromKey(msExport.anBoard, &pmr->sb.key);
+                    msExport.anDice[0] = pnextmr->anDice[0];
+                    msExport.anDice[1] = pnextmr->anDice[1];
+                    if (i & 1)
+                        SwapSides(msExport.anBoard);
+                    ExportSnowieTxt(buffer, &msExport);
 
-                /* I don't understand why we need to swap this field! */
-                ct = strstr(buffer, ";");
-                ct[7] = '0' + ('1' - ct[7]);
+                    /* I don't understand why we need to swap this field! */
+                    ct = strstr(buffer, ";");
+                    if (ct == NULL || strlen(ct) < 8) {
+                        g_assert_not_reached();
+                        fprintf(pf, "Corrupt Snowie position string (%s)\n", buffer);
+                    } else
+                        ct[7] = (ct[7] == '0') ? '1' : '0';
+                }
             }
             if (!(i & 1))
                 if (fSst)
@@ -1168,7 +1233,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
 
         if ((n = GameStatus((ConstTanBoard) anBoard, ms.bgv))) {
             fprintf(pf, "%sWins %d point%s%s\n\n",
-                    i & 1 ? "                                  " : "\n      ",
+                    (i & 1) ? "                                  " : "\n      ",
                     n * nFileCube, n * nFileCube > 1 ? "s" : "", "" /* FIXME " and the match" if appropriate */ );
         }
         i++;
@@ -1181,6 +1246,7 @@ ExportGameGam(char *sz, int fSst)
 {
 
     FILE *pf;
+    int fDontClose = FALSE;
 
     sz = NextToken(&sz);
 
@@ -1195,16 +1261,17 @@ ExportGameGam(char *sz, int fSst)
     if (!confirmOverwrite(sz, fConfirmSave))
         return;
 
-    if (!strcmp(sz, "-"))
+    if (!strcmp(sz, "-")) {
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+        fDontClose = TRUE;
+    } else if (!(pf = g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
 
     ExportGameJF(pf, plGame, -1, FALSE, fSst);
 
-    if (pf != stdout)
+    if (!fDontClose)
         fclose(pf);
 
     setDefaultFileName(sz);
@@ -1229,8 +1296,9 @@ ExportMatchMat(char *sz, int fSst)
 {
 
     FILE *pf;
-    int i;
     listOLD *pl;
+    int i;
+    int fDontClose = FALSE;
 
     /* FIXME what should be done if nMatchTo == 0? */
 
@@ -1247,9 +1315,10 @@ ExportMatchMat(char *sz, int fSst)
     if (!confirmOverwrite(sz, fConfirmSave))
         return;
 
-    if (!strcmp(sz, "-"))
+    if (!strcmp(sz, "-")) {
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+        fDontClose = TRUE;
+    } else if (!(pf = g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -1263,8 +1332,26 @@ ExportMatchMat(char *sz, int fSst)
             fprintf(pf, "; [Round \"%s\"]\n", mi.pchRound);
         if (mi.nYear > 1900)
             fprintf(pf, "; [EventDate \"%4u.%02u.%02u\"]\n", mi.nYear, mi.nMonth, mi.nDay);
-        if (ms.bgv == VARIATION_NACKGAMMON)
+        switch (ms.bgv) {
+        case VARIATION_NACKGAMMON:
             fprintf(pf, "; [Variation \"NackGammon\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_1:
+            fprintf(pf, "; [Variation \"HyperGammon (1)\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_2:
+            fprintf(pf, "; [Variation \"HyperGammon (2)\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_3:
+            fprintf(pf, "; [Variation \"HyperGammon (3)\"]\n");
+            break;
+        case VARIATION_STANDARD:
+            break;
+        default:
+            g_assert_not_reached();
+            break;
+        }
+
         if (mi.pchAnnotator)
             fprintf(pf, "; [Transcriber \"%s\"]\n", mi.pchAnnotator);
         if (mi.pchComment) {
@@ -1285,7 +1372,7 @@ ExportMatchMat(char *sz, int fSst)
     for (i = 0, pl = lMatch.plNext; pl != &lMatch; i++, pl = pl->plNext)
         ExportGameJF(pf, pl->p, i, TRUE, fSst);
 
-    if (pf != stdout)
+    if (!fDontClose)
         fclose(pf);
 
     setDefaultFileName(sz);
